@@ -12,7 +12,6 @@ BUILD_IMAGE="${BUILD_IMAGE:-false}"
 BAREMETAL_DATA_FILE=${BAREMETAL_DATA_FILE:-'/tmp/baremetal.json'}
 ENABLE_KEYSTONE="${ENABLE_KEYSTONE:-false}"
 ZUUL_BRANCH=${ZUUL_BRANCH:-}
-ZUUL_REF=${ZUUL_REF:-}
 
 # Set defaults for ansible command-line options to drive the different
 # tests.
@@ -25,7 +24,6 @@ ZUUL_REF=${ZUUL_REF:-}
 # placed in the configuration drive. The "build image" test does not
 # use cirros.
 
-VM_MEMORY_SIZE="3072"
 VM_DOMAIN_TYPE=qemu
 export VM_DISK_CACHE="unsafe"
 TEST_VM_NUM_NODES=1
@@ -81,6 +79,8 @@ mysql_setup() {
 # Setup openstack_citest database if run in OpenStack CI.
 if [ "$ZUUL_BRANCH" != "" ] ; then
     mysql_setup
+    sudo mkdir -p /opt/libvirt/images
+    VM_SETUP_EXTRA="-e test_vm_storage_pool_path=/opt/libvirt/images"
 fi
 
 if [ ${USE_VENV} = "true" ]; then
@@ -102,7 +102,6 @@ fi
 
 # Adjust options for DHCP, VM, or Keystone tests
 if [ ${USE_DHCP} = "true" ]; then
-    VM_MEMORY_SIZE="1024"
     ENABLE_INSPECTOR=false
     INSPECT_NODES=false
     TEST_VM_NUM_NODES=5
@@ -149,13 +148,13 @@ ${ANSIBLE} -vvvv \
        test-bifrost-create-vm.yaml \
        -e ansible_python_interpreter="${ANSIBLE_PYTHON_INTERP}" \
        -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
-       -e test_vm_memory_size=${VM_MEMORY_SIZE} \
+       -e test_vm_memory_size=${VM_MEMORY_SIZE:-512} \
        -e test_vm_domain_type=${VM_DOMAIN_TYPE} \
+       -e test_vm_disk_gib=${VM_DISK:-5} \
        -e baremetal_json_file=${BAREMETAL_DATA_FILE} \
        -e enable_venv=${ENABLE_VENV} \
-       -e bifrost_venv_dir=${VENV-}
-
-
+       -e bifrost_venv_dir=${VENV-} \
+       ${VM_SETUP_EXTRA:-}
 
 if [ ${USE_DHCP} = "true" ]; then
     # reduce the number of nodes in JSON file
